summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:51:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:51:17 -0600
commit9ab01fb063378430e26c1173aeade68ea8f50a6c (patch)
tree62e9c5e1a8599bf930bd480e58ef0cd75a42be5d
parent9950392af60b1672bd69498b5eaa5f86636acee7 (diff)
downloadkoffice-9ab01fb0.tar.gz
koffice-9ab01fb0.zip
Rename KDEHOME and KDEDIR
-rw-r--r--INSTALL2
-rw-r--r--acinclude.m426
-rw-r--r--configure.in2
-rw-r--r--doc/chalk/tutorial-select-layer.docbook2
-rw-r--r--filters/kword/msword/README2
-rw-r--r--kexi/3rdparty/kexisql/Makefile.msvc6
-rw-r--r--kexi/3rdparty/kexisql3/Makefile.msvc6
-rw-r--r--kexi/3rdparty/kexisql3/Makefile.msvc.release6
-rw-r--r--kexi/tests/newapi/newapi.pro2
-rw-r--r--kexi/tests/parser/parser.pro2
-rwxr-xr-xkpresenter/scripts/mkstandalone.sh38
-rw-r--r--lib/kofficeui/Makefile.am2
12 files changed, 48 insertions, 48 deletions
diff --git a/INSTALL b/INSTALL
index 3a1a94ab..b97518dd 100644
--- a/INSTALL
+++ b/INSTALL
@@ -104,7 +104,7 @@ KDE Specific
If you use ./configure --prefix to install KOffice in a different
location than the rest of KDE, you need to tell KDE about it.
-For this, either set $KDEDIRS so that it contains both prefixes,
+For this, either set $TDEDIRS so that it contains both prefixes,
or add this to /etc/kderc :
[Directories]
prefixes=/the/prefix/I/used/to/install/koffice/
diff --git a/acinclude.m4 b/acinclude.m4
index ce4327b1..861ec05c 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -382,13 +382,13 @@ same compiler to compile Qt and tdelibs as you did use now.
For more details about this problem, look at the end of config.log.])
fi
-if eval `KDEDIR= ./conftest 2>&5`; then
+if eval `TDEDIR= ./conftest 2>&5`; then
kde_result=done
else
kde_result=problems
fi
-KDEDIR= ./conftest 2> /dev/null >&5 # make an echo for config.log
+TDEDIR= ./conftest 2> /dev/null >&5 # make an echo for config.log
kde_have_all_paths=yes
KDE_SET_PATHS($kde_result)
@@ -547,11 +547,11 @@ Please check whether you installed aRts correctly or use
AC_DEFUN([KDE_SET_DEFAULT_BINDIRS],
[
kde_default_bindirs="/usr/bin /usr/local/bin /opt/local/bin /usr/X11R6/bin /opt/kde/bin /opt/trinity/bin /usr/kde/bin /usr/local/kde/bin"
- test -n "$KDEDIR" && kde_default_bindirs="$KDEDIR/bin $kde_default_bindirs"
- if test -n "$KDEDIRS"; then
+ test -n "$TDEDIR" && kde_default_bindirs="$TDEDIR/bin $kde_default_bindirs"
+ if test -n "$TDEDIRS"; then
kde_save_IFS=$IFS
IFS=:
- for dir in $KDEDIRS; do
+ for dir in $TDEDIRS; do
kde_default_bindirs="$dir/bin $kde_default_bindirs "
done
IFS=$kde_save_IFS
@@ -613,7 +613,7 @@ AC_DEFUN([KDE_SUBST_PROGRAMS],
if test -n "$MEINPROC" -a "$MEINPROC" != "compiled"; then
kde_sharedirs="/usr/share/kde /usr/local/share /usr/share /opt/trinity/share /opt/kde/share $prefix/share"
- test -n "$KDEDIR" && kde_sharedirs="$KDEDIR/share $kde_sharedirs"
+ test -n "$TDEDIR" && kde_sharedirs="$TDEDIR/share $kde_sharedirs"
AC_FIND_FILE(apps/ksgmltools2/customization/kde-chunk.xsl, $kde_sharedirs, KDE_XSL_STYLESHEET)
if test "$KDE_XSL_STYLESHEET" = "NO"; then
KDE_XSL_STYLESHEET=""
@@ -1785,7 +1785,7 @@ fi
if test -z "$1"; then
kde_incdirs="$kde_libs_prefix/include /usr/lib/kde/include /usr/local/kde/include /usr/local/include /usr/kde/include /usr/include/kde /usr/include /opt/trinity/include /opt/kde/include $x_includes $qt_includes"
-test -n "$KDEDIR" && kde_incdirs="$KDEDIR/include $KDEDIR/include/kde $KDEDIR $kde_incdirs"
+test -n "$TDEDIR" && kde_incdirs="$TDEDIR/include $TDEDIR/include/kde $TDEDIR $kde_incdirs"
kde_incdirs="$ac_kde_includes $kde_incdirs"
AC_FIND_FILE($kde_check_header, $kde_incdirs, kde_incdir)
ac_kde_includes="$kde_incdir"
@@ -1797,7 +1797,7 @@ So, check this please and use another prefix!])
fi
kde_libdirs="$kde_libs_prefix/lib${tdelibsuff} /usr/lib/kde/lib${tdelibsuff} /usr/local/kde/lib${tdelibsuff} /usr/kde/lib${tdelibsuff} /usr/lib${tdelibsuff}/kde /usr/lib${tdelibsuff}/trinity /usr/lib${tdelibsuff} /usr/X11R6/lib${tdelibsuff} /usr/local/lib${tdelibsuff} /opt/trinity/lib${tdelibsuff} /opt/kde/lib${tdelibsuff} /usr/X11R6/kde/lib${tdelibsuff}"
-test -n "$KDEDIR" && kde_libdirs="$KDEDIR/lib${tdelibsuff} $KDEDIR $kde_libdirs"
+test -n "$TDEDIR" && kde_libdirs="$TDEDIR/lib${tdelibsuff} $TDEDIR $kde_libdirs"
kde_libdirs="$ac_kde_libraries $libdir $kde_libdirs"
AC_FIND_FILE($kde_check_lib, $kde_libdirs, kde_libdir)
ac_kde_libraries="$kde_libdir"
@@ -3537,7 +3537,7 @@ AC_CANONICAL_SYSTEM
AC_ARG_PROGRAM
AM_INIT_AUTOMAKE($1, $2)
AM_DISABLE_LIBRARIES
-AC_PREFIX_DEFAULT(${KDEDIR:-/usr/local/kde})
+AC_PREFIX_DEFAULT(${TDEDIR:-/usr/local/kde})
AC_CHECK_COMPILERS
KDE_PROG_LIBTOOL
AM_KDE_WITH_NLS
@@ -4936,12 +4936,12 @@ AC_DEFUN([KDE_CONF_FILES],
dnl This sets the prefix, for arts and tdelibs
dnl Do NOT use in any other module.
-dnl It only looks at --prefix, KDEDIR and falls back to /usr/local/kde
+dnl It only looks at --prefix, TDEDIR and falls back to /usr/local/kde
AC_DEFUN([KDE_SET_PREFIX_CORE],
[
unset CDPATH
- dnl make $KDEDIR the default for the installation
- AC_PREFIX_DEFAULT(${KDEDIR:-/usr/local/kde})
+ dnl make $TDEDIR the default for the installation
+ AC_PREFIX_DEFAULT(${TDEDIR:-/usr/local/kde})
if test "x$prefix" = "xNONE"; then
prefix=$ac_default_prefix
@@ -4965,7 +4965,7 @@ AC_DEFUN([KDE_SET_PREFIX],
unset CDPATH
dnl We can't give real code to that macro, only a value.
dnl It only matters for --help, since we set the prefix in this function anyway.
- AC_PREFIX_DEFAULT(${KDEDIR:-the kde prefix})
+ AC_PREFIX_DEFAULT(${TDEDIR:-the kde prefix})
KDE_SET_DEFAULT_BINDIRS
if test "x$prefix" = "xNONE"; then
diff --git a/configure.in b/configure.in
index 1ec137ef..85d90cf1 100644
--- a/configure.in
+++ b/configure.in
@@ -2622,7 +2622,7 @@ if test -n "$kde_libs_prefix" -a -n "$given_prefix"; then
echo "Warning: you chose to install this package in $given_prefix,"
echo "but KDE was found in $kde_libs_prefix."
echo "For this to work, you will need to tell KDE about the new prefix, by ensuring"
- echo "that KDEDIRS contains it, e.g. export KDEDIRS=$given_prefix:$kde_libs_prefix"
+ echo "that TDEDIRS contains it, e.g. export TDEDIRS=$given_prefix:$kde_libs_prefix"
echo "Then restart KDE."
echo ""
fi
diff --git a/doc/chalk/tutorial-select-layer.docbook b/doc/chalk/tutorial-select-layer.docbook
index 65a7b6ee..350ed31b 100644
--- a/doc/chalk/tutorial-select-layer.docbook
+++ b/doc/chalk/tutorial-select-layer.docbook
@@ -18,7 +18,7 @@
<para>
The image above is the image we will work with. Start chalk with this
image (in the documentation folder
-<filename>$<envar>KDEDIR</envar>/share/doc/HTML/en/chalk/tutorial-select-layer-sample.png</filename>)
+<filename>$<envar>TDEDIR</envar>/share/doc/HTML/en/chalk/tutorial-select-layer-sample.png</filename>)
and save it to your Home folder (by choosing <guilabel>Save Image As...</guilabel>).
Then open it in &chalk; &mdash; your screen will look a bit like this (we have
diff --git a/filters/kword/msword/README b/filters/kword/msword/README
index cc4fe90c..113dde80 100644
--- a/filters/kword/msword/README
+++ b/filters/kword/msword/README
@@ -24,7 +24,7 @@ independent project). To build it you have to:
take a look at Makefile.am, you might have to uncomment some compile flags.
In case that doesn't fix your problem please send a bug report to
koffice@kde.org (you don't have to be subscribed to post there).
-6) Ensure that the file $KDEDIR/share/services/ole_winword97_import.desktop
+6) Ensure that the file $TDEDIR/share/services/ole_winword97_import.desktop
doesn't exist on your system. If you installed all of KOffice HEAD it should
be gone already.
diff --git a/kexi/3rdparty/kexisql/Makefile.msvc b/kexi/3rdparty/kexisql/Makefile.msvc
index 0be28d92..192ae293 100644
--- a/kexi/3rdparty/kexisql/Makefile.msvc
+++ b/kexi/3rdparty/kexisql/Makefile.msvc
@@ -103,7 +103,7 @@ UICIMPLS =
SRCMOC =
OBJMOC =
DIST =
-TARGET = $(KDEDIR)/bin/kexisql2_d.dll
+TARGET = $(TDEDIR)/bin/kexisql2_d.dll
####### Implicit rules
@@ -148,9 +148,9 @@ $(TARGET): $(UICDECLS) $(OBJECTS) $(OBJMOC)
$(OBJECTS) $(OBJMOC) $(LIBS)
<<
-sqlite2: obj/shell.obj $(KDEDIR)/bin/kexisql2.lib
+sqlite2: obj/shell.obj $(TDEDIR)/bin/kexisql2.lib
link $(READLINE_FLAGS) $(LIBPTHREAD) \
- /OUT:$(KDEDIR)/bin/ksqlite2.exe obj/shell.obj $(KDEDIR)/bin/kexisql2.lib $(LIBREADLINE)
+ /OUT:$(TDEDIR)/bin/ksqlite2.exe obj/shell.obj $(TDEDIR)/bin/kexisql2.lib $(LIBREADLINE)
mocables: $(SRCMOC)
uicables: $(UICIMPLS) $(UICDECLS)
diff --git a/kexi/3rdparty/kexisql3/Makefile.msvc b/kexi/3rdparty/kexisql3/Makefile.msvc
index 0ee21895..d01b5de1 100644
--- a/kexi/3rdparty/kexisql3/Makefile.msvc
+++ b/kexi/3rdparty/kexisql3/Makefile.msvc
@@ -139,7 +139,7 @@ UICIMPLS =
SRCMOC =
OBJMOC =
DIST =
-TARGET = $(KDEDIR)/bin/kexisql3_d.dll
+TARGET = $(TDEDIR)/bin/kexisql3_d.dll
####### Implicit rules
@@ -209,9 +209,9 @@ $(TARGET): $(UICDECLS) $(OBJECTS) $(OBJMOC)
$(OBJECTS) $(OBJMOC) $(LIBS)
<<
-sqlite: src/shell.c $(KDEDIR)/bin/kexisql3_d.lib
+sqlite: src/shell.c $(TDEDIR)/bin/kexisql3_d.lib
link $(READLINE_FLAGS) $(LIBPTHREAD) \
- /OUT:$(KDEDIR)/bin/ksqlite.exe obj/shell.obj $(KDEDIR)/bin/kexisql3_d.lib $(LIBREADLINE)
+ /OUT:$(TDEDIR)/bin/ksqlite.exe obj/shell.obj $(TDEDIR)/bin/kexisql3_d.lib $(LIBREADLINE)
mocables: $(SRCMOC)
uicables: $(UICIMPLS) $(UICDECLS)
diff --git a/kexi/3rdparty/kexisql3/Makefile.msvc.release b/kexi/3rdparty/kexisql3/Makefile.msvc.release
index a6a9fd73..6d443f7d 100644
--- a/kexi/3rdparty/kexisql3/Makefile.msvc.release
+++ b/kexi/3rdparty/kexisql3/Makefile.msvc.release
@@ -139,7 +139,7 @@ UICIMPLS =
SRCMOC =
OBJMOC =
DIST =
-TARGET = $(KDEDIR)/bin/kexisql3.dll
+TARGET = $(TDEDIR)/bin/kexisql3.dll
####### Implicit rules
@@ -209,9 +209,9 @@ $(TARGET): $(UICDECLS) $(OBJECTS) $(OBJMOC)
$(OBJECTS) $(OBJMOC) $(LIBS)
<<
-sqlite: src/shell.c $(KDEDIR)/bin/kexisql3.lib
+sqlite: src/shell.c $(TDEDIR)/bin/kexisql3.lib
link $(READLINE_FLAGS) $(LIBPTHREAD) \
- /OUT:$(KDEDIR)/bin/ksqlite.exe obj_rel/shell.obj $(KDEDIR)/bin/kexisql3.lib $(LIBREADLINE)
+ /OUT:$(TDEDIR)/bin/ksqlite.exe obj_rel/shell.obj $(TDEDIR)/bin/kexisql3.lib $(LIBREADLINE)
mocables: $(SRCMOC)
uicables: $(UICIMPLS) $(UICDECLS)
diff --git a/kexi/tests/newapi/newapi.pro b/kexi/tests/newapi/newapi.pro
index 9caf6926..b16fa6d3 100644
--- a/kexi/tests/newapi/newapi.pro
+++ b/kexi/tests/newapi/newapi.pro
@@ -24,7 +24,7 @@ QMAKE_CXXFLAGS += $(KEXI_OPTIONS)
CONFIG -= windows
}
-DESTDIR = . # no # $KDEDIR/bin
+DESTDIR = . # no # $TDEDIR/bin
TARGET = kexidbtest
SOURCES = \
diff --git a/kexi/tests/parser/parser.pro b/kexi/tests/parser/parser.pro
index 4629417a..f0a46018 100644
--- a/kexi/tests/parser/parser.pro
+++ b/kexi/tests/parser/parser.pro
@@ -15,7 +15,7 @@ QMAKE_CXXFLAGS += $(KEXI_OPTIONS)
CONFIG -= windows
}
-DESTDIR = . # no # $KDEDIR/bin
+DESTDIR = . # no # $TDEDIR/bin
TARGET = parser
SOURCES = \
diff --git a/lib/kofficeui/Makefile.am b/lib/kofficeui/Makefile.am
index 133673f2..d274e9ac 100644
--- a/lib/kofficeui/Makefile.am
+++ b/lib/kofficeui/Makefile.am
@@ -45,7 +45,7 @@ include_HEADERS = \
# FIXME: Disabled for now as it breaks the installation process if
-# KOffice is not installed in $KDEDIR
+# KOffice is not installed in $TDEDIR
#
#AM_CXXFLAGS = -DQT_PLUGIN
#kde_widget_LTLIBRARIES = kofficewidgets.la
diff --git a/kpresenter/scripts/mkstandalone.sh b/kpresenter/scripts/mkstandalone.sh
index ebd2fd8a..b362ee36 100755
--- a/kpresenter/scripts/mkstandalone.sh
+++ b/kpresenter/scripts/mkstandalone.sh
@@ -1,7 +1,7 @@
#!/bin/sh
# This script copies everything that is needed to run kpresenter on a
# computer where KDE isn't installed.
# Relies on kpresenter being installed on the local machine, in $KDEDIR
#
# The script copies everything into a directory. You just need to tar it up,
# transfer it (CD-ROM or via Internet), untar it, cd into it,
@@ -20,30 +20,30 @@ else
mkdir -p $out
mkdir -p $out/share
mkdir -p $out/share/apps
- cp -r $KDEDIR/share/apps/kpresenter $out/share/apps/
- cp -r $KDEDIR/share/apps/koffice $out/share/apps/
- cp -r $KDEDIR/share/apps/kstyle $out/share/apps/
+ cp -r $TDEDIR/share/apps/kpresenter $out/share/apps/
+ cp -r $TDEDIR/share/apps/koffice $out/share/apps/
+ cp -r $TDEDIR/share/apps/kstyle $out/share/apps/
mkdir -p $out/share/config
- cp $KDEDIR/share/config/kdebug.areas $out/share/config/
+ cp $TDEDIR/share/config/kdebug.areas $out/share/config/
cp ~/.kde/share/config/kdeglobals $out/share/config/
cp ~/.kde/share/config/kpresenterrc $out/share/config/
- ### cp $KDEDIR/share/icons $out/share/
- cp -r $KDEDIR/share/toolbar $out/share/
+ ### cp $TDEDIR/share/icons $out/share/
+ cp -r $TDEDIR/share/toolbar $out/share/
mkdir -p $out/share/servicetypes
- cp $KDEDIR/share/servicetypes/kofficepart.desktop $out/share/servicetypes
+ cp $TDEDIR/share/servicetypes/kofficepart.desktop $out/share/servicetypes
mkdir -p $out/share/applnk
- cp $KDEDIR/share/applnk/KOffice/kpresenter.desktop $out/share/applnk/
+ cp $TDEDIR/share/applnk/KOffice/kpresenter.desktop $out/share/applnk/
########### Libraries (warning, using Linux specific ldd !)
TMPFILE=/tmp/__kpresenter_ldd.tmp
mkdir -p $out/lib
- ldd $KDEDIR/bin/kpresenter | sed -e 's/.*=> \([^ ]*\).*/\1/' > $TMPFILE
+ ldd $TDEDIR/bin/kpresenter | sed -e 's/.*=> \([^ ]*\).*/\1/' > $TMPFILE
# Add style libs
- echo $KDEDIR/lib/basicstyle.so >> $TMPFILE
- echo $KDEDIR/lib/kstepstyle.so >> $TMPFILE
+ echo $TDEDIR/lib/basicstyle.so >> $TMPFILE
+ echo $TDEDIR/lib/kstepstyle.so >> $TMPFILE
# Add image handler libs
- echo $KDEDIR/lib/kimg_jpeg.so >> $TMPFILE
- echo $KDEDIR/lib/kimg_tiff.so >> $TMPFILE
+ echo $TDEDIR/lib/kimg_jpeg.so >> $TMPFILE
+ echo $TDEDIR/lib/kimg_tiff.so >> $TMPFILE
# Add libs for embedded parts here
cat $TMPFILE | while read libfile; do
@@ -69,16 +69,16 @@ else
########### Binaries
mkdir -p $out/bin
- cp $KDEDIR/bin/kpresenter $out/bin/
- cp $KDEDIR/bin/dcopserver $out/bin/
+ cp $TDEDIR/bin/kpresenter $out/bin/
+ cp $TDEDIR/bin/dcopserver $out/bin/
# Take kded as well - we could copy the ksycoca file but we would have
# to install it in ~/.kde ...
- cp $KDEDIR/bin/kded $out/bin/
+ cp $TDEDIR/bin/kded $out/bin/
########### Startup script
echo '#!/bin/sh' > $out/go.sh
- echo 'export KDEDIR=`pwd`' >> $out/go.sh
- echo 'export LD_LIBRARY_PATH=$KDEDIR/lib' >> $out/go.sh
+ echo 'export TDEDIR=`pwd`' >> $out/go.sh
+ echo 'export LD_LIBRARY_PATH=$TDEDIR/lib' >> $out/go.sh
echo 'mkdir -p ~/.kde 2>/dev/null' >> $out/go.sh
echo 'mkdir -p ~/.kde/share 2>/dev/null' >> $out/go.sh
echo 'mkdir -p ~/.kde/share/config 2>/dev/null' >> $out/go.sh
@@ -1,7 +1,7 @@
# This script copies everything that is needed to run kpresenter on a
# computer where KDE isn't installed.
-# Relies on kpresenter being installed on the local machine, in $KDEDIR
+# Relies on kpresenter being installed on the local machine, in $TDEDIR
#
# The script copies everything into a directory. You just need to tar it up,